|PyPI Version| |Build Status| |Coverage Status| |Python Version|

This Python package provides a command-line tool and library to index OCDS documentation in Elasticsearch 7.x.

To install:

.. code-block:: bash

   pip install ocdsindex

If you are viewing this on GitHub or PyPI, open the `full documentation <https://ocds-index.readthedocs.io/>`__ for additional details.

.. |PyPI Version| image:: https://img.shields.io/pypi/v/ocdsindex.svg
   :target: https://pypi.org/project/ocdsindex/
.. |Build Status| image:: https://github.com/open-contracting/ocds-index/workflows/CI/badge.svg
   :target: https://github.com/open-contracting/ocds-index/actions?query=workflow%3ACI
.. |Coverage Status| image:: https://coveralls.io/repos/github/open-contracting/ocds-index/badge.svg?branch=main
   :target: https://coveralls.io/github/open-contracting/ocds-index?branch=main
.. |Python Version| image:: https://img.shields.io/pypi/pyversions/ocdsindex.svg
   :target: https://pypi.org/project/ocdsindex/
